%bcond_with opt
%if %{with opt}
%define _prefix /opt
%define __cmake cmake
%endif

# unpack_module_source():
# we check if we should build a given package
# if so, we unpack sources and add entry to config
# %1 - source number
# %2 - subpackage name

%define unpack_module_source() \
%if %{with %2}\
%setup -q -D -T -a %1 -n kadu/modules\
sed "s#^module_%2=.#module_%2=m#" -i ../.config\
%endif\
%nil

# enable_module():
# enable these internal modules which are not
# enabled by default

%define enable_module() \
sed "s#^module_%1=.#module_%1=m#" -i ./.config\
%nil

# module_files():
# both internal and external modules have at least their .so, .ui,
# .desc and .qm files. In order to simplify things, this macro 
# creates a simple %files section
# %1 - module/subpackage name
# if parameter -d is specified, module owns its data dir
# 
# all modules have very similar directory and files structure, so
# this macro is created to make it possible to simplify %files
# sections. All modules have .desc and .so files, a lot of them
# has configurations and translations or data dirs. We use 
# respectively -c, -t and -d parameters to know which files
# a module owns.

%define module_files(d,c,t) \
%{_libdir}/kadu/modules/lib%{1}.so\
%{_datadir}/kadu/modules/%1.desc\
%if "%{-c}" \
%{_datadir}/kadu/modules/configuration/%1.ui\
%endif\
%if "%{-t}" \
%{_datadir}/kadu/modules/translations/%{1}*.qm\
%endif\
%if "%{-d}" \
%{_datadir}/kadu/modules/data/%1\
%endif\
%nil

# kadu.spec
# table to make it possible to find out quickly which
# subpackage has which source's number
# LAST NUMBER: 120
# 117 anonymous_check
# 102 globalhotkeys
# 104 led_notify
# 111 mail
# 112 mime_tex
# 115 osd_hints
# 114 panelkadu
# 105 plus_pl_sms
# 118 powerkadu
# 103 senthistory
# 120 split_messages
# 106 tabs
# the modules above aren't all external modules
# so here's the full list
# anonymous_check
# globalhotkeys
# led_notify
# mail
# mime_tex
# panelkadu
# plus_pl_sms
# powerkadu
# senthistory
# split_messages
# tabs


# whether we want to build certain subpackages or not
# some of them are disabled by default due to
# not being adjusted to kadu-0.6.5
%bcond_without anonymous_check
%bcond_without globalhotkeys
%bcond_without led_notify
%bcond_without mail
%bcond_without mime_tex
%bcond_without osd_hints
%bcond_without panelkadu
%bcond_without plus_pl_sms
%bcond_without powerkadu
%bcond_without senthistory
%bcond_without split_messages
%bcond_without tabs


%if ! %{with opt}
Name:		kadu
%else
Name:		kadu_opt
%endif
Version:	0.6.5.2
Release:	3%{?dist}
Summary:	An Gadu-Gadu client for online messaging
Summary(pl):	Klient Gadu-Gadu
Group:		Applications/Internet
License:	GPLv2
URL:		http://www.kadu.net
Source0:	http://www.kadu.net/download/stable/kadu-%{version}.tar.bz2
Source3:	kadu.desktop

# external modules:
%if %{with anonymous_check}
Source117:	http://kadu.net/~patryk/anonymous_check/anonymous_check-0.6.5.1.tar.bz2
%endif
%if %{with globalhotkeys}
Source102:	http://www.ultr.pl/kadu/globalhotkeys-0.6.5-10.tar.gz
%endif
%if %{with led_notify}
Source104:	http://kadu.net/~blysk/led_notify-0.21.tar.bz2
%endif
%if %{with mail}
Source111:      http://kadu.net/~michal/mail/mail-current.tar.bz2
%endif
%if %{with plus_pl_sms}
Source105:	http://kadu.net/~patryk/plus_pl_sms/plus_pl_sms-0.6.5.1.tar.bz2
%endif
%if %{with mime_tex}
Source112:      http://kadu.net/~patryk/mime_tex/mime_tex-0.6.5.3.tar.bz2
%endif
%if %{with osd_hints}
Source115:	http://www.kadu.net/~dorr/moduly/kadu-osd_hints-0.1.3.tar.bz2
%endif
%if %{with panelkadu}
Source114:	http://www.ultr.pl/kadu/panelkadu-0.6.5-3.tar.gz
%endif
%if %{with powerkadu}
Source118:	http://www.kadu.net/~dorr/moduly/kadu-powerkadu-2.1.2.tar.bz2
%endif
%if %{with senthistory}
Source103:	http://www.ultr.pl/kadu/senthistory-0.6.5-4.tar.gz
%endif
%if %{with split_messages}
Source120:	http://www.kadu.net/~dorr/moduly/kadu-split_messages-0.3.tar.bz2
%endif
%if %{with tabs}
Source106:	http://www.kadu.net/~arvenil/tabs/download/0.6.5/kadu-tabs-1.2.3.tar.bz2
%endif

#Patch0:		kadu-0.6.0-xmmsfix.patch
Patch0:		kadu-0.6.5-voice-external-libgsm.patch
Patch1:		kadu-gcc44.patch
# Sent to kadu-security [AT] kadu [DOT] net on 2009/04/24
Patch2:		kadu-profiles-fix.patch
# http://www.kadu.net/forum/viewtopic.php?t=9862 (in Polish)
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:  cmake
BuildRequires:	libpng-devel libsndfile-devel openssl-devel
BuildRequires:	qt-devel
BuildRequires:	libgadu-devel > 1.8.0
BuildRequires:	gsm-devel
BuildRequires:  desktop-file-utils
BuildRequires:	aspell-devel alsa-lib-devel
BuildRequires:	libao-devel
BuildRequires:	libXScrnSaver-devel
BuildRequires:	qca2-devel
Obsoletes:	%{name}-ext_info < 0.6.0-0.1.alpha1
Obsoletes:	%{name}-iwait4u < 0.6.0-0.1.alpha1
Obsoletes:	%{name}-wmaker_docking < 0.6.0-0.1.alpha1
Obsoletes:	%{name}-arts_sound < 0.6.5-0.1.rc2 
#support for arts has been dropped, we've got qt4_sound now
Obsoletes:	%{name}-dcopexport < 0.6.5-0.1.rc2 
#dropped, there is no more DCOP in QT4
Obsoletes:	%{name}-agent < 0.6.5-2
Obsoletes:	%{name}-alsa_sound < 0.6.5-2
Provides:	%{name}-alsa_sound = %{version}-%{release}
Obsoletes:	%{name}-advanced_userlist < 0.6.0-0.1.alpha1
Provides:	%{name}-advanced_userlist = %{version}-%{release}
Obsoletes:	%{name}-amarok_mediaplayer < 0.6.5-2
Obsoletes:	%{name}-antistring < 0.6.5-2
Provides:	%{name}-antistring = %{version}-%{release}
Obsoletes:	%{name}-audacious_mediaplayer < 0.6.5-2
Obsoletes:	%{name}-exec_notify < 0.6.0-0.1.alpha1
Provides:	%{name}-exec_notify = %{version}-%{release}
Obsoletes:	%{name}-cenzor < 0.6.5-1
Provides:	%{name}-cenzor = %{version}-%{release}
Obsoletes:	%{name}-devel < 0.6.5-0.1.rc2
Obsoletes:	%{name}-ao_sound < 0.6.5-0.1.rc2
Provides:	%{name}-ao_sound = %{version}-%{release}
Obsoletes:	%{name}-autostatus < 0.6.5-0.1.rc2
Provides:	%{name}-autostatus = %{version}-%{release}
Obsoletes:	%{name}-auto_hide < 0.6.5-0.1.rc2
Provides:	%{name}-auto_hide = %{version}-%{release}
Obsoletes:	%{name}-esd_sound < 0.6.5-2
Obsoletes:	%{name}-falf_mediaplayer < 0.6.5-2
Obsoletes:	%{name}-filedesc < 0.6.5-0.1.rc2
Provides:	%{name}-filedesc = %{version}-%{release}
Obsoletes:	%{name}-filtering < 0.6.5-0.1.rc2
Provides:	%{name}-filtering = %{version}-%{release}
Obsoletes:	%{name}-firewall < 0.6.5-0.1.rc2
Provides:	%{name}-firewall = %{version}-%{release}
Obsoletes:	%{name}-last_seen < 0.6.5-0.1.rc2
Provides:	%{name}-last_seen = %{version}-%{release}
Obsoletes:	%{name}-mediaplayer < 0.6.5-0.1.rc2
Obsoletes:	%{name}-mx610_notify < 0.6.5-2
Obsoletes:	%{name}-parser_extender < 0.6.5-0.1.rc2
Provides:	%{name}-parser_extender = %{version}-%{release}
Obsoletes:	%{name}-pcspeaker < 0.6.5-0.1.rc2
Provides:	%{name}-pcspeaker = %{version}-%{release}
Obsoletes:	%{name}-profiles < 0.6.5-0.1.rc2
Provides:	%{name}-profiles = %{version}-%{release}
Obsoletes:	%{name}-screenshot < 0.6.5-1
Provides:	%{name}-screenshot = %{version}-%{release}
Obsoletes:	%{name}-spellchecker < 0.6.5-1
Provides:	%{name}-spellchecker = %{version}-%{release}
Obsoletes:	%{name}-water_notify < 0.6.5-2
Obsoletes:	%{name}-weather < 0.6.5-2
Obsoletes:	%{name}-word_fix < 0.6.5-0.1.rc2
Provides:	%{name}-word_fix = %{version}-%{release}
Obsoletes:	%{name}-xmms_mediaplayer < 0.6.5-2



%description
Kadu is a dynamically evolving instant messenger compatible with the Gadu-Gadu
protocol.

%description -l pl
Kadu to dynamicznie rozwijający się komunikator internetowy kompatybilny z
protokołem Gadu-Gadu.


%if %{with anonymous_check}
%package anonymous_check
Summary:        Automatic lookup of an interlocutor in public directory
Summary(pl):    Automatyczne wyszukiwanie nieznajomych w katalogu
Group:          Applications/Internet
Requires:       %{name} = %{version}-%{release}

%description anonymous_check
Anonymous_check is a module to automatic lookup who is an interlocutor
when (s)he starts talking to you.

%description anonymous_check -l pl
Anonymous_check to moduł, która automatycznie sprawdza dane w publicznym
katalogu nieznajomego, gdy ten zagada.

%endif


%if %{with globalhotkeys}
%package globalhotkeys
Summary:        Global hotkeys support to Kadu
Summary(pl):    Obsługa skrótów globalnych
Group:          Applications/Internet
Requires:       %{name} = %{version}-%{release}

%description globalhotkeys
Globalhotkeys is a module that adds support to global
hotkeys in kadu.

%description globalhotkeys -l pl
Globalhotkeys to moduł dodający obsługę skrótów globalnych
w kadu.

%endif


%if %{with led_notify}
%package led_notify
Summary:	Notification by Scroll Lock LED
Summary(pl):	Powiadamianie diodą Scroll Lock
Group:		Applications/Internet
Requires:	%{name} = %{version}-%{release}
%description led_notify
Led_notify is a module to notify user of some events using Scroll Lock
LED.


%description led_notify -l pl
Led_notify to moduł umożliwiający powiadamianie użytkownika o pewnych
zdarzenia przy użyciu diody Scroll Lock.

%endif

%if %{with mail}
%package mail
Summary:	Mail checking module
Summary(pl):	Moduł do sprawdzania poczty
Group:          Applications/Internet
Requires:       %{name} = %{version}-%{release}
%description mail
Mail is a module to check whether there are new mails.

%description mail -l pl
Mail to moduł do sprawdzania czy są nowe maile.

%endif

%if %{with mime_tex}
%package mime_tex
Summary:	TeX formulas support
Summary(pl):	Obsługa formuł matematycznych TeX
Group:          Applications/Internet
Requires:       %{name} = %{version}-%{release}
%description mime_tex
Mime_tex is a module to edit TeX mathematic formulas in chat window.

%description mime_tex -l pl
Mime_tex to moduł umożliwiający edycję formuł matematycznych TeX
w oknie rozmowy.

%endif


%if %{with plus_pl_sms}
%package plus_pl_sms
Summary:	Miasto Plusa SMS gateway support
Summary(pl):	Obsługa bramki SMS Miasto Plusa
Group:		Applications/Internet
Requires:	%{name} = %{version}-%{release}
Obsoletes:	%{name}-miastoplusa_sms < 0.6.5-0.1.rc2
Provides:	%{name}-miastoplusa_sms = %{version}-%{release}
BuildRequires:	curl-devel
%description plus_pl_sms
Plus_pl_sms is a module to support Plus.pl SMS Gateway.

%description plus_pl_sms -l pl
Plus_pl_sms to moduł umożliwiający obsługę bramki SMS-owej "Plus.pl".

%endif


%if %{with osd_hints}
%package osd_hints
Summary:	Notification by OSD-like hints
Summary(pl):	Powiadamanie o zdarzeniach przy pomocy dymków typu OSD
Group:          Applications/Internet
Requires:       %{name} = %{version}-%{release}
Obsoletes:	%{name}-osdhints_notify < 0.6.5-1
Provides:	%{name}-osdhints_notify = %{version}-%{release}
%description osd_hints
Osd_hints is a module to notify users about some events
with OSD-like hints.

%description osd_hints -l pl
Osd_hints to moduł umożliwiający powiadamianie użytkownika
o pewnych zdarzeniach przy pomocy dymków typu OSD.

%endif

%if %{with panelkadu}
%package panelkadu
Summary:	Makes a panel from Kadu main window
Summary(pl):	Zamienia Kadu w panel na skraju ekranu
Group:          Applications/Internet
Requires:       %{name} = %{version}-%{release}
BuildRequires:  libXtst-devel
%description panelkadu
Panelkadu is a module to make a panel from Kadu main window.

%description panelkadu -l pl
Panelkadu to moduł zamieniający kadu w panel na skraju ekranu.

%endif


%if %{with powerkadu}
%package powerkadu
Summary:        PowerKadu
Summary(pl):    PowerKadu
Group:          Applications/Internet
Requires:       %{name} = %{version}-%{release}
Requires:	%{name}-anonymous_check = %{version}-%{release}
#Requires:	kadu-antistring = %{version}-%{release}
#Requires:	kadu-auto_hide = %{version}-%{release}
#Requires:	kadu-parser_extender = %{version}-%{release}
Requires:	%{name}-split_messages = %{version}-%{release}
#Requires:	kadu-word_fix = %{version}-%{release}

#All submodules except anonymous-check and split_messages are now merged into kadu core, 
#so powerkadu shouldn't require them.
 
%description powerkadu
PowerKadu is a metapackage which contains modules known from the "old"
powerkadu.

%description powerkadu -l pl
PowerKadu to teraz metapakiet, który zawiera moduły znane ze "starego"
powerkadu.

%endif

%if %{with senthistory}
%package senthistory
Summary:	History of sent messages in chat windows
Summary(pl):	Historia wysłanych wiadomości w oknie rozmowy
Group:		Applications/Internet
Requires:	%{name} = %{version}-%{release}
%description senthistory
Senthistory is a module which adds history of sent messages to
chat windows.

%description senthistory -l pl
Senthistory to moduł, który dodaje historię wysłanych wiadomości
do okien rozmowy.

%endif

%if %{with split_messages}
%package split_messages
Summary:        Split too long messages
Summary(pl):    Dzielenie zbyt długich wiadomości
Group:          Applications/Internet
Requires:       %{name} = %{version}-%{release}

%description split_messages
Split_messages is a module to split a message to smaller parts
if it's too long.

%description split_messages -l pl
Split_messages to moduł dzielący wiadomość na mniejsze części,
jeśli jest za długa.

%endif

%if %{with tabs}
%package tabs
Summary:	Tabbed chat dialog
Summary(pl):	Okno rozmowy z zakładkami
Group:		Applications/Internet
Requires:	%{name} = %{version}-%{release}
%description tabs
Tabs is a module to add a feature to use one window to talk with all
people and use cards to switch them.

%description tabs -l pl
Tabs to moduł dodający możliwość prowadzenia rozmów w jednym oknie,
w którym pomiędzy poszczególnymi rozmówcami przełącza się przy pomocy
zakładek.

%endif

%prep
%setup -q -n kadu
%unpack_module_source 117 anonymous_check
%unpack_module_source 102 globalhotkeys
%unpack_module_source 104 led_notify
%unpack_module_source 111 mail
%unpack_module_source 112 mime_tex
%unpack_module_source 115 osd_hints
%unpack_module_source 114 panelkadu
%unpack_module_source 105 plus_pl_sms
%unpack_module_source 118 powerkadu
%unpack_module_source 103 senthistory
%unpack_module_source 120 split_messages
%unpack_module_source 106 tabs
%setup -q -D -T -n kadu

#internal modules
%enable_module alsa_sound
%enable_module antistring
%enable_module ao_sound
%enable_module auto_hide
%enable_module autostatus
%enable_module cenzor
%enable_module filedesc
%enable_module filtering
%enable_module firewall
%enable_module gg_avatars
%enable_module last_seen
%enable_module qt4_docking
%enable_module qt4_sound
%enable_module parser_extender
%enable_module pcspeaker
%enable_module profiles
%enable_module screenshot
%enable_module spellchecker
%enable_module word_fix

# exec_notify and ext_sound have always been standard modules
# so let's keep it this way
sed "s#^module_exec_notify=.#module_exec_notify=m#" -i .config
sed "s#^module_ext_sound=.#module_ext_sound=m#" -i .config

sed "s#^icons_glass16=.#icons_glass16=n#" -i .config
sed "s#^icons_glass22=.#icons_glass22=n#" -i .config


#let's not annoy users with update notifies
#and disable them

pushd kadu-core
sed "/CheckUpdates/s#true#false#" -i kadu.cpp
popd

# force the right lib path and set DETAILED_VERSION
sed 's#set (LIBDIR ${CMAKE_INSTALL_PREFIX}/lib)#set (LIBDIR %{_libdir})#' -i CMakeLists.txt
sed 's@#define DETAILED.*@#define DETAILED_VERSION "%{name}-%{version}-%{release}"@' -i kadu-config.h.cmake

# fix mediaplayer plugin bug
#echo 'install (FILES "data/mediaplayer.png" DESTINATION "share/kadu/modules/data/mediaplayer")' >> modules/mediaplayer/CMakeLists.txt

%patch0
%patch1
%patch2

%build
%{cmake} -DCMAKE_BUILD_TYPE=Debug -DCMAKE_USE_PTHREADS:BOOL=ON -DBUILD_DESCRIPTION="Fedora" .
make -k VERBOSE=1 %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
rm -rf $RPM_BUILD_ROOT%{_datadir}/applnk/Internet/kadu.desktop
rm -rf $RPM_BUILD_ROOT%{_datadir}/applications/kadu.desktop
desktop-file-install --vendor fedora				\
	--dir ${RPM_BUILD_ROOT}%{_datadir}/applications		\
	%{SOURCE3}

if [ "x%{_lib}" != "xlib" ]; then
	mv $RPM_BUILD_ROOT%{_prefix}/lib $RPM_BUILD_ROOT%{_libdir}
fi


%clean
rm -rf $RPM_BUILD_ROOT

%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files
%defattr(-,root,root,-)

%doc COPYING
%{_bindir}/kadu
%{_datadir}/applications/fedora-kadu.desktop
%dir %{_libdir}/kadu
%dir %{_libdir}/kadu/modules
%dir %{_datadir}/kadu
%{_datadir}/kadu/syntax
%{_datadir}/kadu/AUTHORS
%{_datadir}/kadu/ChangeLog
%{_datadir}/kadu/COPYING
%{_datadir}/kadu/HISTORY
%{_datadir}/kadu/README
%{_datadir}/kadu/THANKS
%{_datadir}/kadu/configuration
%dir %{_datadir}/kadu/modules
%dir %{_datadir}/kadu/modules/configuration
%dir %{_datadir}/kadu/modules/data
%dir %{_datadir}/kadu/modules/translations
%dir %{_datadir}/kadu/themes
%dir %{_datadir}/kadu/themes/emoticons
%{_datadir}/kadu/themes/emoticons/penguins
%dir %{_datadir}/kadu/themes/icons
%{_datadir}/kadu/themes/icons/default
%dir %{_datadir}/kadu/themes/sounds
%{_datadir}/kadu/themes/sounds/default
%{_datadir}/kadu/translations
%{_datadir}/kadu/modules/docking.desc
%{_datadir}/kadu/modules/configuration/docking.ui
%{_datadir}/kadu/modules/translations/docking_*.qm
%{_datadir}/icons/hicolor/*/apps/kadu.png

# internal modules:
%module_files account_management -t
%module_files advanced_userlist -ct
%module_files alsa_sound -ct
%module_files antistring -cdt
%module_files ao_sound
%module_files auto_hide -ct
%module_files autoaway -ct
%module_files autoresponder -ct
%module_files autostatus -ct
%module_files cenzor -cdt
%module_files config_wizard -td
%module_files dcc -ct
%module_files default_sms -ct
%module_files dsp_sound -ct
%module_files encryption -ct
%module_files exec_notify -t
%module_files ext_sound -ct
%module_files filedesc -ct
%module_files filtering -cdt
%module_files firewall -ct
%module_files gg_avatars -t
%module_files hints -ct
%module_files history -ct
%module_files idle
%module_files last_seen -t
#module_files mediaplayer -cdt
%module_files notify -ct
%module_files qt4_docking
%module_files qt4_sound
%module_files parser_extender -ct
%module_files pcspeaker -ct
%module_files profiles -t
%module_files screenshot -ct
%module_files sms -ct
%module_files sound -ct
%module_files spellchecker -ct
%module_files voice -ct
%module_files window_notify -t
%module_files word_fix -cdt

# external modules:

%if %{with anonymous_check}
%files anonymous_check
%defattr(-, root, root, -)
%module_files anonymous_check -ct
%endif


%if %{with globalhotkeys}
%files globalhotkeys
%defattr(-, root, root, -)
%module_files globalhotkeys -ct
%endif

%if %{with led_notify}
%files led_notify
%defattr(-, root, root, -)
%module_files led_notify -ct
%endif

%if %{with mail}
%files mail
%defattr(-, root, root, -)
%module_files mail -ct
%endif

%if %{with plus_pl_sms}
%files plus_pl_sms
%defattr(-, root, root, -)
%module_files plus_pl_sms -cdt
%endif

%if %{with mime_tex}
%files mime_tex
%defattr(-, root, root, -)
%module_files mime_tex -cdt
%{_libdir}/kadu/modules/bin/mime_tex
%endif

%if %{with osd_hints}
%files osd_hints
%defattr(-, root, root, -)
%module_files osd_hints -cdt
%endif

%if %{with panelkadu}
%files panelkadu
%defattr(-, root, root, -)
%module_files panelkadu -ct
%endif

%if %{with powerkadu}
%files powerkadu
%defattr(-, root, root, -)
%module_files powerkadu -dt
%endif

%if %{with senthistory}
%files senthistory
%defattr(-, root, root, -)
%module_files senthistory -ct
%endif

%if %{with split_messages}
%files split_messages
%defattr(-, root, root, -)
%module_files split_messages -ct
%endif


%if %{with tabs}
%files tabs
%defattr(-, root, root, -)
%module_files tabs -ct
%endif


%changelog
* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 0.6.5.2-3
- rebuilt with new openssl

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.5.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri May 08 2009 Dawid Gajownik <gajownik[AT]gmail.com> - 0.6.5.2-1
- Update to 0.6.5.2
- Update kadu-gcc44.patch
- Added BuildRequires qca2-devel and libXScrnSaver-devel
- Updated globalhotkeys, mime_tex, osd_hints, panelkadu, powerkadu,
  senthistory and tabs modules
- Package idle and gg_avatars modules
- Handle properly icons
- Add kadu-profiles-fix.patch

* Fri Apr 24 2009 Milos Jakubicek <xjakub@fi.muni.cz> - 0.6.5-10
- Fix FTBFS: added kadu-gcc44.patch

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.6.5-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Sat Jan 17 2009 Tomas Mraz <tmraz@redhat.com> - 0.6.5-8
- rebuild with new openssl

* Tue Dec 16 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-7
- Osd_hints tarball was missing in sources

* Tue Dec 16 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-6
- Enable kadu-osd_hints by default

* Tue Dec 16 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-5
- Fix conflicts with kadu-osd_hints and kadu-agent

* Wed Dec 10 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-4
- More cleaning

* Tue Dec 09 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-3
- Fix bz #475629

* Tue Dec 09 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-2
- Fix kadu-0.6.5 bug and install sounds to proper directory

* Wed Dec 03 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.5-1
- 0.6.5
- Lots of changes:
-    some modules are now considered default,
-    some others are disabled,
-    some no longer exists,
-    some changed name,
- Parameter "--with=opt" given to rpmbuild makes kadu build to
  /opt instead of /usr (useful feature in testing)
- Kadu now uses qt4
- Lots of Obsoletes/Provides to prevent breaking updates
- Etc.

* Mon May 19 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0.1-1
- 0.6.0.1
- New version of mime_tex, tabs, firewall, osd_hints, powerkadu,
audacious_mediaplayer
- New url of ao_sound
- New modules: autostatus, last_seen, globalhotkeys
- Panelkadu requires libXtst-devel to build

* Tue Apr 01 2008 Rex Dieter <rdieter@fedoraproject.org> - 0.6.0-3
- -devel: qt3-devel (f9+)

* Wed Mar 12 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-2
- Fix bugs 436574 (f8) and 436575 (f7)
- New versions of tabs and osd_hints
- New modules: anonymous_check antistring auto_hide cenzor parser_extender 
powerkadu split_messages word_fix


* Thu Feb 28 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-1
- Stable
- New versions of osd_hints, audacious_mediaplayer, filtering,
mediaplayer and panelkadu

* Mon Feb 18 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.12.rc4
- rc4
- Add modules: water_notify, osd_hints, panelkadu

* Wed Feb 13 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.11.rc3
- rc3
- New firewall module
- New versions of some modules

* Sun Feb 03 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.10.rc2.try2
- rc2-try2

* Sun Feb 03 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.9.rc2
- rc2
- New versions of led_notify, weather, pcspeaker, mime_tex, tabs,
mediaplayer, xmms_mediaplayer and mail modules
- Add filtering module
- Get rid of xmmsfix patch
- Fix mail module

* Sun Jan 13 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.8.rc1
- rc1
- New mx610_notify, falf_mediaplayer, mail and mime_tex modules.
- New versions of some modules

* Sun Jan 06 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.7.beta2
- Fix bug 427679 (add forgotten %% symbol in one place)

* Sun Jan 06 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.6.beta2
- Now forgot to include that one source changed its name

* Sun Jan 06 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.5.beta2
- Forgot to upload some sources...

* Sat Jan 05 2008 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.4.beta2
- beta2
- Add kadu-agent

* Fri Dec 21 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.3.beta1
- 0.6.0-beta1
- Changes of almost everything, spec file has been completely rewritten
- Get rid of stupid macros including %%{_kadudir} and %%{_modtrans}
- Make it possible to build any subpackages whoever wants, no need to build
all
- Add Polish descriptions to all subpackages and change English ones
- There are too many changes to list all of them ;-)
- Hope it's now much more readable and user-friendly

* Wed Dec 19 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.2.alpha2
- 0.6.0-alpha2
- New pcspeaker module
- New version of miastoplusa_sms, profiles, dcopexport

* Sat Dec 01 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.6.0-0.1.alpha1
- 0.6.0-alpha1
- remove xmms, amarok, mail, extinfo, iwait4u, powerkadu, advanced_userlist, osd_hints, screenshot, firewall, filedesc
- update spellchecker, weather, dcopexport, miastopolusa_sms, tabs, led_notify, filtering
- get rid of tabs patch
- add filedesc, spellchecker and firewall patches
- exec_notify is now built-in

* Fri Aug 24 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-4
- Fix desktop file

* Fri Aug 24 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-3
- BuildID rebuild
- Fix License tag

* Thu Apr 05 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-2
- Own %%{_datadir}/kadu/modules/data (BZ: 233855)

* Tue Jan 02 2007 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-1
- Finally a stable release

* Mon Dec 25 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.21.rc2
- Bump to RC2

* Mon Nov 14 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.20.rc1
- Add advanced_userlist, osd_hints and screenshot modules

* Wed Nov 08 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.19.rc1
- Update kadu to RC1
- Update ext_info module to 2.0beta9
- Update powerkadu module to 20061026
- Update xmms module to 1.32
- Update amarok module to 1.19
- Amarok builds on all architectures again
- Add tabs patch

* Thu Nov 02 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.18.20060915svn
- Come back to 20060915

* Sun Oct 29 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.17.20061029svn
- Disabling kadu-amarok on ppc arch

* Sun Oct 29 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.16.20061029svn
- Bump cvs snapshot to 20061029

* Tue Oct 10 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.15.20060915svn
- Another fix to not rebuilding kadu-amarok

* Sat Oct 07 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.14.20060915svn
- It really shoud work now

* Sat Oct 07 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.13.20060915svn
- It should work now

* Fri Oct 06 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.12.20060915svn
- Yet another fix...

* Fri Oct 06 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.11.20060915svn
- Rpmbuild build error workaround.

* Fri Oct 06 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.10.20060915svn
- Not rebuilding kadu-amarok on some archs

* Sat Sep 16 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.9.20060915svn
- Update upstream to 20060915
- Move themes to external spec file
- Link to existing libgadu

* Mon Sep 04 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.8.20006808svn
- FC6 rebuild

* Fri Aug 11 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.7.20060808svn
- Update upstream to 20060808
- Add firewall and wmaker_docking modules

* Sun Jul 30 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.6.20060730svn
- Update upstream do 20060730, with fixed x64 bugs
- Add mail module and emots theme

* Thu Jul 27 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.5.20060727svn
- Delete qt dependency
- Exclude libgadu.a file
- Add powerkadu, filtering and profiles modules

* Mon Jul 24 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.4.20060716svn
- Add COPYING file to doc

* Sun Jul 23 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.3.20060716svn
- Yet another fix permissions of .so files

* Sun Jul 23 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.2.20060716svn
- Fix Source0 address
- Fix permissions of .so files
- Remove libsndfile require
- Fix some descriptions of subpackages
- Add --enable-debug and --disable-dependency-tracking options to configure

* Thu Jul 20 2006 Michał Bentkowski <mr.ecik at gmail.com> - 0.5.0-0.1.20060716svn
- Another first release


